@@ -2,7 +2,8 @@
 #define SAGEM_H
 
 #include "pirkeysetmetadata.h"
-#include <QObject>
+
+class QObject;
 
 class SagemTVBox1: public PIRKeysetMetaData
 {
