@@ -34,14 +34,17 @@ enum PIRMakeName{
   Raite_Make,
   RCA_Make,
   Roku_Make,
+  Saba_Make,
   Sagem_Make,
   Samsung_Make,
   Sanyo_Make,
   Sharp_Make,
+  Sky_Make,
   Sony_Make,
   Tivo_Make,
   Topfield_Make,
   Toshiba_Make,
+  WD_Make,
   Westinghouse_Make,
   Yamaha_Make,
   Zenith_Make
